@@ -19,20 +19,23 @@
  ***************************************************************************/
 #include "kkaprintstatuswidget.h"
 
-#include <klocale.h>
 #include <qradiobutton.h>
 
+#include <klocale.h>
+
 using namespace KKAddressBook;
 
 KKAPrintStatusWidget::KKAPrintStatusWidget( QWidget* parent, const char* name )
  : QHButtonGroup( parent, name )
 {
 	setInsideMargin( 0 );
-	setFlat( true );
+	setLineWidth( 0 );
+/*	setFlat( true );*/
 	QRadioButton* radio = new QRadioButton( i18n( "None" ), this );
 	radio = new QRadioButton( i18n( "Print" ), this );
 	radio = new QRadioButton( i18n( "Printed" ), this );
 	connect( this, SIGNAL( clicked( int ) ), this, SLOT( buttonClicked( int ) ) );
+	setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed );
 }
 
 
