@@ -17,8 +17,6 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-
-
 #ifndef _KKAWIDGET_H_
 #define _KKAWIDGET_H_
 
@@ -45,7 +43,7 @@ namespace KKAddressBook
 	{
 		Q_OBJECT
 	public:
-		KKAWidget( KKDesigner::KKDDoc* doc, KCommandHistory* cmdHistory, QWidget* parent = 0, const char* name = 0 );
+		KKAWidget( KCommandHistory* cmdHistory, QWidget* parent = 0, const char* name = 0 );
 		virtual ~KKAWidget();
 		const char* xmlFile(){ return "kkaddressbookui.rc"; }
 		bool closable();
@@ -55,7 +53,9 @@ namespace KKAddressBook
 		QPtrList<KKAContactData> printData();
 		
 	public slots:
-		void tabChanged( QWidget* wgt );
+		void tabChanged( bool enabled );
+		void setDocument( KKDesigner::KKDDoc* doc ) { m_doc = doc; }
+		void setSender( const KKAddressBook::KKAContactData* s );
 
 	private slots:
 		void groupChanged( QListViewItem* g );
@@ -64,6 +64,9 @@ namespace KKAddressBook
 		void importContactXML();
 		void exportContactXML();
 		
+		void importKAddressBook();
+		void exportKAddressBook();
+		
 		void togglePreview();
 
 	private:
@@ -76,6 +79,7 @@ namespace KKAddressBook
 		KKDesigner::KKDDoc* m_doc;
 		QListViewItem* m_data;
 		QStringList m_strlActions;
+		const KKAddressBook::KKAContactData* m_sender;
 	};
 }
 
