@@ -37,19 +37,20 @@ KKDAddressee::KKDAddressee( const QPoint& l
 						  , const QFont& f
 						  , const QColor& c
 						  , Orientation o
+						  , DataType t
 						  , QObject* parent
 						  )
-	: KKDTextBase( l, s, f, c, o, parent )
+	: KKDDataBase( l, s, f, c, o, t, parent )
 {
 }
 
 KKDAddressee::KKDAddressee( QDomElement e, QObject* parent )
-	: KKDTextBase( e, parent )
+	: KKDDataBase( e, parent )
 {
 }
 
 KKDAddressee::KKDAddressee( const KKDAddressee* item, QObject* parent )
-	: KKDTextBase( (KKDTextBase*)item, parent )
+	: KKDDataBase( (KKDDataBase*)item, parent )
 {
 }
 
@@ -60,12 +61,13 @@ KKDAddressee::~KKDAddressee()
 QDomElement KKDAddressee::toElement( QDomDocument& doc, const QString& t )
 {
 	QString tag( t == QString::null ? tagName() : t );
-	return KKDTextBase::toElement( doc, tag );
+	return KKDDataBase::toElement( doc, tag );
 }
 
 void KKDAddressee::drawItemBefore( QRect& r, QPainter& p, DrawMode m, const KKAddressBook::KKAContactData* d )
 {
-	KKDTextBase::drawItemBefore( r, p, m, d );
+	KKDDataBase::drawItemBefore( r, p, m, d );
+	
 	switch( m )
 	{
 		case AddressMode:
@@ -86,14 +88,22 @@ void KKDAddressee::drawItemBefore( QRect& r, QPainter& p, DrawMode m, const KKAd
 			}
 			break;
 		default:
-			drawText( r, p, AlignCenter, i18n( "@Addressee" ) );
+			switch( dataType() )
+			{
+				case Receiver:
+					drawText( r, p, AlignCenter, i18n( "@Addressee" ) );
+					break;
+				case Sender:
+					drawText( r, p, AlignCenter, i18n( "#Addressee" ) );
+					break;
+			}
 			break;
 	}
 }
 
 void KKDAddressee::drawItemAfter( QRect& r, QPainter& p, DrawMode m, const KKAddressBook::KKAContactData* d )
 {
-	KKDTextBase::drawItemAfter( r, p, m, d );
+	KKDDataBase::drawItemAfter( r, p, m, d );
 	switch( m )
 	{
 		case DesignMode:
@@ -226,7 +236,8 @@ void KKDAddressee::drawTextHome( QRect& r, QPainter& p, const KKAddressBook::KKA
 		}
 		case Vertical:
 		{
-			int width = 0;
+			int total_width = 0;
+			int width[persons.count()];
 			int height[4] = { 0, 0, 0, 0 };
 			QSize layout[persons.count()][4];
 			uint max_length[4] = { 0, 0, 0, 0 };
@@ -235,8 +246,8 @@ void KKDAddressee::drawTextHome( QRect& r, QPainter& p, const KKAddressBook::KKA
 			int sep_height = 0;
 			while( 1 )
 			{
+				total_width = 0;
 				sep_height = calcSize( " ", size_decrease ).width() / 2;
-				width = 0;
 				for( int i = 0; i != 4; i++ )
 				{
 					height[i] = 0;
@@ -245,6 +256,7 @@ void KKDAddressee::drawTextHome( QRect& r, QPainter& p, const KKAddressBook::KKA
 				QSize totalSize;
 				for( uint i = 0; i != persons.count(); i++ )
 				{
+					width[i] = 0;
 					QSize s = calcSize( persons.at( i )->prefix(), size_decrease );
 					if( height[0] < s.height() ) height[0] = s.height();
 					if( max_length[0] < persons.at( i )->prefix().length() ) max_length[0] = persons.at( i )->prefix().length();
@@ -265,8 +277,12 @@ void KKDAddressee::drawTextHome( QRect& r, QPainter& p, const KKAddressBook::KKA
 					if( max_length[3] < persons.at( i )->suffix().length() ) max_length[3] = persons.at( i )->suffix().length();
 					layout[i][3] = s;
 
-					width += layout[i][2].width();
-					totalSize.setWidth( layout[i][2].width() );
+					for( int j = 0; j != 4; j++ )
+					{
+						width[i] = QMAX( width[i], layout[i][j].width() );
+					}
+					totalSize.setWidth( totalSize.width() + width[i] );
+					total_width += width[i];
 				}
 				totalSize.setHeight( height[0] + height[1] + height[2] + height[3]
 								 	 + ( height[0] == 0 ? 0 : sep_height )
@@ -283,10 +299,10 @@ void KKDAddressee::drawTextHome( QRect& r, QPainter& p, const KKAddressBook::KKA
 				}
 			}
 
-			rct.setWidth( width / persons.count() );
-			if( rect().width() > width )
+			rct.setWidth( total_width / persons.count() );
+			if( rect().width() > total_width )
 			{
-				rct.moveRight( rect().right() - ( rect().width() - width ) / 2 );
+				rct.moveRight( rect().right() - ( rect().width() - total_width ) / 2 );
 			}
 			else
 			{
@@ -295,6 +311,7 @@ void KKDAddressee::drawTextHome( QRect& r, QPainter& p, const KKAddressBook::KKA
 
 			for( uint i = 0; i != persons.count(); i++ )
 			{
+				rct.setLeft( rct.right() - width[i] );
 				int name_height = rect().height() - sep_height * 2;
 				if( height[0] > 0 ) name_height -= height[0] + sep_height;
 				if( height[3] > 0 ) name_height -= height[3] + sep_height;
@@ -343,7 +360,7 @@ void KKDAddressee::drawTextHome( QRect& r, QPainter& p, const KKAddressBook::KKA
 					drawText( rct, p, AlignTop, persons.at( i )->suffix(), size_decrease );
 					rct.moveTop( rct.top() + height[3] );
 				}
-				rct.moveRight( rct.right() - width / persons.count() );
+				rct.moveRight( rct.right() - width[i] );
 			}
 
 			break;
