@@ -26,9 +26,10 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kmainwindow.h>
-#include <tkcoloractions.h>
+// #include <tkcoloractions.h>
 #include <kfiledialog.h>
 #include <kcursor.h>
+#include <kpopupmenu.h>
 
 #include "kkddoc.h"
 #include "kkdcanvas.h"
@@ -54,7 +55,9 @@ KKDCanvas::KKDCanvas( KKDItemBase::DrawMode m, KKDPaper* paper, QWidget* parent,
 	, m_zoom( 1 )
 	, m_mode( m )
 	, m_data( NULL )
+	, m_sender( NULL )
 {
+	setFocusPolicy( QWidget::StrongFocus );
 	connect( m_paper, SIGNAL( repaint( const QRect& ) ), this, SLOT( slotRepaint( const QRect& ) ) );
 	connect( m_paper, SIGNAL( imageChanged() ), this, SLOT( imageChanged() ) );
 	connect( document(), SIGNAL( currentChanged( KKDPaper* ) ), this, SLOT( currentChanged( KKDPaper* ) ) );
@@ -147,7 +150,22 @@ void KKDCanvas::draw( const QPaintDevice* device, QRect rect )
 	{
 		if( item->rect().intersects( rect ) )
 		{
-			item->drawItem( p, m_mode, m_data );
+			if( item->inherits( "KKDesigner::KKDDataBase" ) )
+			{
+				switch( ((KKDDataBase*)item)->dataType() )
+				{
+					case KKDDataBase::Receiver:
+						item->drawItem( p, m_mode, m_data );
+						break;
+					case KKDDataBase::Sender:
+						item->drawItem( p, m_mode, m_sender );
+						break;
+				}
+			}
+			else
+			{
+				item->drawItem( p, m_mode );
+			}
 		}
 	}
 	p.end();
@@ -549,7 +567,8 @@ void KKDCanvas::mouseReleaseEvent( QMouseEvent* e )
 					font.setItalic( ((KToggleAction*)action( "fontitalic" ))->isChecked() );
 					font.setUnderline( ((KToggleAction*)action( "fontunderline" ))->isChecked() );
 					font.setStrikeOut( ((KToggleAction*)action( "fontstrikeout" ))->isChecked() );
-					QColor color( ((TKSelectColorAction*)action( "color" ))->color() );
+// 					QColor color( ((TKSelectColorAction*)action( "color" ))->color() );
+					QColor color( black );
 					QString str;
 					if( m_dragMode == InsertText )
 					{
@@ -601,7 +620,7 @@ void KKDCanvas::mouseReleaseEvent( QMouseEvent* e )
 							break;
 						}
 						case InsertZipcode:
-							item = new KKDZipcode( QPoint( x, y ), QSize( w, h ), font, color, Horizontal, m_paper );
+							item = new KKDZipcode( QPoint( x, y ), QSize( w, h ), font, color, Horizontal, KKDDataBase::Receiver, m_paper );
 							break;
 						default:
 						{
@@ -621,10 +640,10 @@ void KKDCanvas::mouseReleaseEvent( QMouseEvent* e )
 							switch( m_dragMode )
 							{
 								case InsertAddressee:
-									item = new KKDAddressee( QPoint( x, y ), QSize( w, h ), font, color, o, m_paper );
+									item = new KKDAddressee( QPoint( x, y ), QSize( w, h ), font, color, o, KKDDataBase::Receiver, m_paper );
 									break;
 								case InsertAddress:
-									item = new KKDAddress( QPoint( x, y ), QSize( w, h ), font, color, o, m_paper );
+									item = new KKDAddress( QPoint( x, y ), QSize( w, h ), font, color, o, KKDDataBase::Receiver, m_paper );
 									break;
 							}
 							break;
@@ -847,16 +866,29 @@ void KKDCanvas::setContactData( const KKAddressBook::KKAContactData* d )
 	}
 }
 
+void KKDCanvas::setSender( const KKAddressBook::KKAContactData* s )
+{
+	m_sender = s;
+	drawData();
+	if( m_sender )
+	{
+		connect( m_sender, SIGNAL( updated() ), this, SLOT( drawData() ) );
+	}
+}
+
 void KKDCanvas::drawData()
 {
 	QPtrList<KKDItemBase> items( *m_paper );
+	QRect r;
 	for( KKDItemBase* item = items.first(); item; item = items.next() )
 	{
-		if( item->isA( "KKDesigner::KKDAddress" )
-		 || item->isA( "KKDesigner::KKDAddressee" )
-		 || item->isA( "KKDesigner::KKDZipcode" ) )
+		if( item->inherits( "KKDesigner::KKDDataBase" ) )
 		{
-			repaint( item->rect(), false );
+			r |= item->rect();
 		}
 	}
+	if( r.isValid() )
+	{
+		repaint( r, false );
+	}
 }
