@@ -75,6 +75,7 @@ namespace KKDesigner
 		void insertAddress();
 		void insertZipcode();
 		void setContactData( const KKAddressBook::KKAContactData* d );
+		void setSender( const KKAddressBook::KKAContactData* s );
 
 	protected:
 		void paintEvent( QPaintEvent* );
@@ -98,6 +99,7 @@ namespace KKDesigner
 		int m_zoom;
 		KKDItemBase::DrawMode m_mode;
 		const KKAddressBook::KKAContactData* m_data;
+		const KKAddressBook::KKAContactData* m_sender;
 
 		QPoint m_fraSelectPos;
 		QRect m_overlay;
