@@ -151,7 +151,52 @@ QString KKDCmdOrientation::propertyName()
 {
 	return i18n( "orientation" );
 }
-//END KKDCmdData
+//END KKDCmdOrientation
+
+//BEGIN KKDCmdDataType
+KKDCmdDataType::KKDCmdDataType( KKDDoc* doc )
+	: KKDCmdBase( doc )
+{
+	connect( this, SIGNAL( executed() ), doc, SIGNAL( dataTypeChanged() ) );
+	connect( this, SIGNAL( unexecuted() ), doc, SIGNAL( dataTypeChanged() ) );
+}
+
+void KKDCmdDataType::execute( KKDItemBase* item )
+{
+	((KKDDataBase*)item)->setDataType( m_after[item] );
+}
+
+void KKDCmdDataType::unexecute( KKDItemBase* item )
+{
+	((KKDDataBase*)item)->setDataType( m_before[item] );
+}
+
+bool KKDCmdDataType::begin( KKDItemBase* item )
+{
+	if( !item->inherits( "KKDesigner::KKDDataBase" ) ) return false;
+	m_before[item] = ((KKDDataBase*)item)->dataType();
+	return true;
+}
+
+bool KKDCmdDataType::end( KKDItemBase* item )
+{
+	bool rtn = ( m_before[item] != ((KKDDataBase*)item)->dataType() );
+	if( rtn )
+	{
+		m_after[item] = ((KKDDataBase*)item)->dataType();
+	}
+	else
+	{
+		m_before.remove( item );
+	}
+	return rtn;
+}
+
+QString KKDCmdDataType::propertyName()
+{
+	return i18n( "dataType" );
+}
+//END KKDCmdDataType
 
 //BEGIN KKDCmdImage
 KKDCmdImage::KKDCmdImage( KKDDoc* doc )
@@ -886,6 +931,7 @@ void KKDCmdRaise::unexecute( KKDItemBase* item )
 
 bool KKDCmdRaise::begin( KKDItemBase* item )
 {
+	if( item->isA( "KKDesigner::KKDPaper" ) ) return false;
 	if( item->locked() ) return false;
 	m_parent[item] = (KKDPaper*)item->parent();
 	m_index[item] = m_parent[item]->containsRef( item );
@@ -928,6 +974,7 @@ void KKDCmdLower::unexecute( KKDItemBase* item )
 
 bool KKDCmdLower::begin( KKDItemBase* item )
 {
+	if( item->isA( "KKDesigner::KKDPaper" ) ) return false;
 	if( item->locked() ) return false;
 	m_parent[item] = (KKDPaper*)item->parent();
 	m_index[item] = m_parent[item]->containsRef( item );
