@@ -126,13 +126,28 @@ void KKDDoc::close()
 	emit documentChanged();
 }
 
-void KKDDoc::print( QPainter& p, KKAddressBook::KKAContactData* d )
+void KKDDoc::print( QPainter& p, KKAddressBook::KKAContactData* receiver, const KKAddressBook::KKAContactData* sender )
 {
 	KKDPaper* paper = current();
-	paper->drawItem( p, KKDItemBase::PrintMode, d );
+	paper->drawItem( p, KKDItemBase::PrintMode, receiver );
 	for( KKDItemBase* item = paper->last(); item; item = paper->prev() )
 	{
-		item->drawItem( p, KKDItemBase::PrintMode, d );
+		if( item->inherits( "KKDesigner::KKDDataBase" ) )
+		{
+			switch( ((KKDDataBase*)item)->dataType() )
+			{
+				case KKDDataBase::Receiver:
+					item->drawItem( p, KKDItemBase::PrintMode, receiver );
+					break;
+				case KKDDataBase::Sender:
+					item->drawItem( p, KKDItemBase::PrintMode, sender );
+					break;
+			}
+		}
+		else
+		{
+			item->drawItem( p, KKDItemBase::PrintMode );
+		}
 	}
 }
 
@@ -875,6 +890,60 @@ void KKDDoc::setFontStrikeOut( bool s )
 }
 //END   FontStrikeOut
 
+//BEGIN DataType
+/**
+ * @english
+ * @retval Receiver All selected items is receiver
+ * @retval Sender All selected items is sender
+ * @retval -1 both receiver and sender
+ * @retval -2 no item is selected
+ * @endenglish
+ */
+KKDDataBase::DataType KKDDoc::dataType() const
+{
+	int t = -2;
+	QPtrList<KKDItemBase> items( m_selectedItems );
+	for( KKDItemBase* item = items.first(); item; item = items.next() )
+	{
+		if( item->inherits( "KKDesigner::KKDDataBase" ) )
+		{
+			if( t == -2 )
+			{
+				t = (int)((KKDDataBase*)item)->dataType();
+			}
+			else if( t != (int)((KKDDataBase*)item)->dataType() )
+			{
+				t = -1;
+				break;
+			}
+		}
+	}
+	return (KKDDataBase::DataType)t;
+}
+
+void KKDDoc::setDataType( KKDDataBase::DataType t )
+{
+	terminate();
+	m_cmd = new KKDCmdDataType( this );
+	m_cmd->begin();
+	for( KKDItemBase* item = m_cmd->items().first(); item; item = m_cmd->items().next() )
+	{
+		((KKDDataBase*)item)->setDataType( t );
+	}
+	m_cmd->end();
+	if( m_cmd->valid() )
+	{
+		m_cmdHistory->addCommand( m_cmd, false );
+		emit dataTypeChanged();
+	}
+	else
+	{
+		delete m_cmd;
+	}
+	m_cmd = NULL;
+}
+//END   DataType
+
 //BEGIN Image
 void KKDDoc::setImage( const QImage &i )
 {
