@@ -52,25 +52,15 @@ using namespace KKDesigner;
 KKDWidget::KKDWidget( KCommandHistory* cmdHistory, QWidget* parent, const char* name )
 	: KKWidgetBase( cmdHistory, parent, name )
 	, m_filename( QString::null )
+	, m_sender( NULL )
 {
+	KAction* act;
 	m_doc = new KKDDoc( cmdHistory, this );
 
 	m_view = new KKDView( KKDItemBase::DesignMode, m_doc, this );
 
-	m_strlActions << "file_open"
-				  << "file_open_recent"
-				  << "file_save"
-				  << "file_save_as"
-				  << "file_print"
-				  << "file_close"
-				  << "edit_cut"
-				  << "edit_copy"
-				  << "edit_paste"
-				  << "edit_select_all"
-				  ;
-
 	//BEGIN File Menu
-	KStdAction::open( this, SLOT( fileOpen() ), actionCollection() );
+	act = KStdAction::open( this, SLOT( fileOpen() ), actionCollection() );
 	KStdAction::openRecent( this, SLOT( openRecent( const KURL& ) ), actionCollection() );
 	KStdAction::save( this, SLOT( fileSave() ), actionCollection() );
 	KStdAction::saveAs( this, SLOT( fileSaveAs() ), actionCollection() );
@@ -85,7 +75,7 @@ KKDWidget::KKDWidget( KCommandHistory* cmdHistory, QWidget* parent, const char*
 	new KAction( i18n( "Insert A&ddress" ), "insert_address", KShortcut(), m_view, SLOT( insertAddress() ), actionCollection(), "insertaddress" );
 	new KAction( i18n( "Insert &Zipcode" ), "insert_zipcode", KShortcut(), m_view, SLOT( insertZipcode() ), actionCollection(), "insertzipcode" );
 
-	new KAction( i18n( "&Delete Item" ), "eraser", KShortcut(Qt::Key_Delete), m_doc, SLOT( remove() ), actionCollection(), "remove" );
+	new KAction( i18n( "&Delete Item" ), "remove_item", KShortcut(Qt::Key_Delete), m_doc, SLOT( remove() ), actionCollection(), "remove" );
 
 	new KAction( i18n( "&Raise" ), "top", 0, m_doc, SLOT( raise() ), actionCollection(), "raise" );
 
@@ -150,6 +140,13 @@ KKDWidget::KKDWidget( KCommandHistory* cmdHistory, QWidget* parent, const char*
 	new KToggleAction( i18n( "Print Image" ), "imagegallery", KShortcut(Qt::CTRL + Qt::Key_I), this, SLOT( setImagePrint() ), actionCollection(), "imageprint" );
 	
 	new KAction( i18n( "&Erase Image" ), "eraser", KShortcut(), m_doc, SLOT( eraseImage() ), actionCollection(), "imageerase" );
+	
+	actR = new KRadioAction( i18n( "Receiver" ), "receiver", 0, this, SLOT( setDataType() ), actionCollection(), "receiver" );
+	actR->setExclusiveGroup( "DataType" );
+
+	actR = new KRadioAction( i18n( "Sender" ), "sender", 0, this, SLOT( setDataType() ), actionCollection(), "sender" );
+	actR->setExclusiveGroup( "DataType" );
+
 	//END Edit Menu
 
 // 	new KAction( i18n( "&Subscribe template" ), "sendtemplate", 0, this, SLOT( subscribeTemplate() ), actionCollection(), "subscribetemplate" );
@@ -178,6 +175,7 @@ KKDWidget::KKDWidget( KCommandHistory* cmdHistory, QWidget* parent, const char*
 	connect( m_doc, SIGNAL( selectedChanged() ), this, SLOT( setActionOrientation() ) );
 	connect( m_doc, SIGNAL( selectedChanged() ), this, SLOT( setActionAlign() ) );
 	connect( m_doc, SIGNAL( selectedChanged() ), this, SLOT( setActionColor() ) );
+	connect( m_doc, SIGNAL( selectedChanged() ), this, SLOT( setActionDataType() ) );
 	connect( m_doc, SIGNAL( selectedChanged() ), this, SLOT( setActionImagePrint() ) );
 	connect( m_doc, SIGNAL( selectedChanged() ), this, SLOT( setActionImageErase() ) );
 
@@ -191,6 +189,7 @@ KKDWidget::KKDWidget( KCommandHistory* cmdHistory, QWidget* parent, const char*
 	connect( m_doc, SIGNAL( orientationChanged() ), this, SLOT( setActionOrientation() ) );
 	connect( m_doc, SIGNAL( alignChanged() ), this, SLOT( setActionAlign() ) );
 	connect( m_doc, SIGNAL( colorChanged() ), this, SLOT( setActionColor() ) );
+	connect( m_doc, SIGNAL( dataTypeChanged() ), this, SLOT( setActionDataType() ) );
 
 	connect( m_doc, SIGNAL( imagePrintChanged() ), this, SLOT( setActionImagePrint() ) );
 
@@ -265,6 +264,7 @@ void KKDWidget::fileOpen( const QString& filename, bool blCheckChanged )
 	setActionOrientation();
 	setActionAlign();
 	setActionColor();
+	setActionDataType();
 	setActionImagePrint();
 	setActionImageErase();
 	QApplication::restoreOverrideCursor();
@@ -370,7 +370,7 @@ void KKDWidget::print()
 					{
 						newPage = true;
 					}
-					m_doc->print( p, d );
+					m_doc->print( p, d, m_sender );
 				}
 
 				d->setCurrent( KKAddressBook::KKAAddressData::Office );
@@ -384,7 +384,7 @@ void KKDWidget::print()
 					{
 						newPage = true;
 					}
-					m_doc->print( p, d );
+					m_doc->print( p, d, m_sender );
 				}
 				d->setCurrent( l );
 			}
@@ -554,6 +554,19 @@ void KKDWidget::setColor()
 	}
 }
 
+void KKDWidget::setDataType()
+{
+	if( ((KRadioAction*)action( "receiver" ))->isChecked() )
+	{
+		m_doc->setDataType( KKDDataBase::Receiver );
+	}
+	else if( ((KRadioAction*)action( "sender" ))->isChecked() )
+	{
+		m_doc->setDataType( KKDDataBase::Sender );
+	}
+	setActionDataType();
+}
+
 void KKDWidget::setImagePrint()
 {
 	m_doc->setImagePrint( ((KToggleAction*)action( "imageprint" ))->isChecked() );
@@ -665,6 +678,26 @@ void KKDWidget::setActionColor()
 // 	((TKSelectColorAction*)action( "color" ))->setCurrentColor( m_doc->color() );
 }
 
+void KKDWidget::setActionDataType()
+{
+	KKDDataBase::DataType t = m_doc->dataType();
+	switch( t )
+	{
+		case KKDDataBase::Receiver:
+			((KRadioAction*)action( "receiver" ))->setChecked( true );
+			break;
+		case KKDDataBase::Sender:
+			((KRadioAction*)action( "sender" ))->setChecked( true );
+			break;
+		case (KKDDataBase::DataType)-1:
+			((KRadioAction*)action( "receiver" ))->setChecked( false );
+			((KRadioAction*)action( "sender" ))->setChecked( false );
+			break;
+	}
+	((KRadioAction*)action( "receiver" ))->setEnabled( t > -2 );
+	((KRadioAction*)action( "sender" ))->setEnabled( t > -2 );
+}
+
 void KKDWidget::setActionImagePrint()
 {
 	((KToggleAction*)action( "imageprint" ))->setChecked( m_doc->imagePrint() );
@@ -699,7 +732,7 @@ void KKDWidget::setActionPasteEnabled()
 void KKDWidget::subscribeTemplate()
 {
 	if( !checkChangedAndSaved() ) return;
-	fileSave();
+// 	m_doc->save( m_filename );
 	KKDSubscribeTemplate::KKDSubscribeTemplateDialog dlg( m_filename, this );
 	for( KKDCanvas* canvas = m_view->canvas().first(); canvas; canvas = m_view->canvas().next() )
 	{
@@ -743,40 +776,65 @@ bool KKDWidget::closable()
 	return checkChangedAndSaved();
 }
 
-void KKDWidget::tabChanged( QWidget* wgt )
+void KKDWidget::tabChanged( bool enabled )
 {
-	bool enabled = ( wgt == this );
-	for( QStringList::ConstIterator it = m_strlActions.begin(); it != m_strlActions.end(); ++it )
+	if( enabled && m_filename.isNull() )
+	{
+		emit openTemplate();
+	}
+	QStringList actions;
+	actions << "file_open"
+			<< "file_open_recent"
+			<< "file_save"
+			<< "file_save_as"
+			<< "file_print"
+			<< "file_close"
+			<< "edit_cut"
+			<< "edit_copy"
+			<< "edit_paste"
+			<< "edit_select_all"
+			<< "edit_deselect"
+			;
+
+	for( QStringList::ConstIterator it = actions.begin(); it != actions.end(); ++it )
 	{
 		setActionEnabled( *it, enabled );
 	}
+	if( enabled )
+	{
+		commandHistory()->updateActions();
+	}
+	else
+	{
+		setActionEnabled( "edit_redo", enabled );
+		setActionEnabled( "edit_undo", enabled );
+	}
 	if( enabled ) setEditActionEnabled();
 	resetCaption();
 }
 
 bool KKDWidget::checkChangedAndSaved()
 {
-	bool blRtn = true;
+	bool rtn = true;
+	bool enabled = action( "edit_undo" )->isEnabled();
+	commandHistory()->updateActions();
 	if( action( "edit_undo" )->isEnabled() )
 	{
 		int ans = KMessageBox::questionYesNoCancel( this, i18n("This document is modified.\nDo you save change?"), i18n("Confirm") );
 		switch( ans )
 		{
 			case KMessageBox::Yes:
-				blRtn = fileSave();
-				if( blRtn )
-				{
-// 					m_doc->commandHistory()->clear();
-				}
-				break;
+				rtn = fileSave();
 			case KMessageBox::No:
+				if( rtn ) commandHistory()->clear();
 				break;
 			case KMessageBox::Cancel:
-				blRtn = false;
+				rtn = false;
 				break;
 		}
 	}
-	return blRtn;
+// 	commandHistory()->updateActions();
+	return rtn;
 }
 
 void KKDWidget::setEditActionEnabled()
@@ -813,6 +871,10 @@ void KKDWidget::setEditActionEnabled()
 	setActionEnabled( "fontstrikeout", enabled );
 
 	setActionEnabled( "color", enabled );
+	
+	setActionEnabled( "receiver", enabled );
+	setActionEnabled( "sender", enabled );
+
 	setActionEnabled( "locked", enabled );
 	setActionEnabled( "imageprint", enabled );
 	setActionEnabled( "imageerase", enabled );
@@ -825,3 +887,8 @@ void KKDWidget::setEditActionEnabled()
 /*	setActionEnabled( "view_zoom_in", enabled );
 	setActionEnabled( "view_zoom_out", false );*/
 }
+
+void KKDWidget::setSender( const KKAddressBook::KKAContactData* s )
+{
+	m_sender = s;
+}
