@@ -23,6 +23,11 @@
 
 #include "../kkwidgetbase.h"
 
+namespace KKAddressBook
+{
+	class KKAContactData;
+}
+
 class KURL;
 /**
  * @namespace KKDesigner
@@ -61,8 +66,12 @@ namespace KKDesigner
 	public slots:
 		void fileNew( const QString& filename );
 		void fileOpen( const QString& filename, bool blCheckChanged = false );
-		void tabChanged( QWidget* wgt );
+		void tabChanged( bool enabled );
+		void setSender( const KKAddressBook::KKAContactData* s );
 
+	signals:
+		void openTemplate();
+		
 	private slots:
 		//BEGIN File Menu
 		void fileOpen();
@@ -86,6 +95,8 @@ namespace KKDesigner
 		void setAlign();
 		void setColor();
 
+		void setDataType();
+		
 		void setImagePrint();
 		//END Edit Menu
 
@@ -101,6 +112,8 @@ namespace KKDesigner
 		void setActionOrientation();
 		void setActionAlign();
 		void setActionColor();
+
+		void setActionDataType();
 		
 		void setActionImagePrint();
 		void setActionImageErase();
@@ -117,9 +130,8 @@ namespace KKDesigner
 		KKDDoc* m_doc;
 		KKDView* m_view;
 
-		QStringList m_strlActions;
-
 		QString m_filename;
+		const KKAddressBook::KKAContactData* m_sender;
 
 		bool checkChangedAndSaved();
 		void setEditActionEnabled();
