@@ -20,55 +20,90 @@
 #include "kktcategoryitem.h"
 #include "kktitem.h"
 
+#include <qfile.h>
+#include <qdom.h>
+#include <qdir.h>
+#include <qregexp.h>
+
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kiconloader.h>
+#include <kmessagebox.h>
 
 using namespace KKTemplate;
 
-KKTCategoryItem::KKTCategoryItem( KListView* parent, QDomElement elem, QString path )
+KKTCategoryItem::KKTCategoryItem( KListView* parent, QString path )
 	: KListViewItem( parent )
 	, m_strPath( path )
 {
-	readData( elem );
+	readMetaData();
+	readChildren();
 	setOpen( true );
 }
 
-KKTCategoryItem::KKTCategoryItem( KListViewItem* parent, QDomElement& elem, QString path )
+KKTCategoryItem::KKTCategoryItem( KListViewItem* parent, QString path )
 	: KListViewItem( parent )
 	, m_strPath( path )
 {
-	readData( elem );
+	readMetaData();
+	readChildren();
 }
 
-void KKTCategoryItem::readData( QDomElement elem )
+void KKTCategoryItem::readMetaData()
 {
 	setPixmap( 0, SmallIcon( "folder" ) );
 
-	if( elem.hasAttribute( "path" ) )
+	QFile file( m_strPath + "metadata.xml" );
+	if( !file.open( IO_ReadOnly ) )
 	{
-		m_strPath += elem.attribute( "path" ) + "/";
+		KMessageBox::error( (QWidget*)parent(), i18n( "File open error\n%1" ).arg( m_strPath ) );
+		return;
 	}
-	QString lang = KGlobal::locale()->language();
-	int i = 0;
-	for( QDomNode node = elem.firstChild(); !node.isNull(); node = node.nextSibling() )
+
+	QDomDocument doc( "kktemplate" );
+	if( !doc.setContent( &file ) )
 	{
-		QDomElement e = node.toElement();
-		if( e.tagName() == "title" )
+		KMessageBox::error( (QWidget*)parent(), i18n( "File is not kreetingkard template format" ) );
+		file.close();
+		return;
+	}
+	file.close();
+
+	QString lang = KGlobal::locale()->language();
+
+	for( QDomNode n = doc.documentElement().firstChild(); !n.isNull(); n = n.nextSibling() )
+	{
+		QDomElement elem = n.toElement();
+		if( elem.tagName() == "category" )
 		{
-			if( ( e.attribute( "lang" ) == "C" && text( 0 ).isEmpty() ) || e.attribute( "lang" ) == lang )
+			if( ( elem.attribute( "lang" ) == "C" && text( 0 ).isEmpty() ) || elem.attribute( "lang" ) == lang )
 			{
-				setText( 0, e.text() );
+				setText( 0, elem.text().remove( '\t' ).remove( '\n' ) );
 			}
 		}
-		else if( e.tagName() == "category" )
+	}
+}
+
+void KKTCategoryItem::readChildren()
+{
+	QRegExp rx( "^([0-9]+)_(.*)$" );
+	QDir dir( m_strPath );
+	QStringList list = dir.entryList( QDir::Dirs|QDir::Readable, QDir::Name );
+
+	for( QStringList::iterator it = list.begin(); it != list.end(); ++it )
+	{
+		if( (*it)[0] != '.' )
 		{
-			( new KKTCategoryItem( this, e, m_strPath ) )->setText( 1, QString( "%1" ).arg( i++, 3 ) );
-		}
-		else if( e.tagName() == "template" )
-		{
-			m_list.append( new KKTItem( e, m_strPath ) );
+			if( rx.search( *it ) > -1 )
+			{
+				KKTCategoryItem* item = new KKTCategoryItem( this, m_strPath + *it + "/" );
+				item->setText( 1, QString( "%1" ).arg( rx.cap( 1 ).toInt(), QString::number( list.size() ).length() ) );
+			}
+			else
+			{
+				m_list.append( new KKTItem( m_strPath + *it + "/" ) );
+			}
 		}
 	}
 	m_list.setAutoDelete( true );
