@@ -20,12 +20,12 @@
 #include "kktcategoryview.h"
 #include "kktcategoryitem.h"
 
+#include <qdir.h>
+
 #include <kdebug.h>
 #include <klocale.h>
 
 #include <kstandarddirs.h>
-#include <qfile.h>
-#include <qdom.h>
 
 using namespace KKTemplate;
 
@@ -47,28 +47,17 @@ KKTCategoryView::~KKTCategoryView()
 void KKTCategoryView::readData()
 {
 	QString path = KGlobal::dirs()->findResource( "data", KGlobal::instance()->instanceName() + "/templates/" );
-	QString datafile = KGlobal::dirs()->findResource( "data", KGlobal::instance()->instanceName() + "/template.xml" );
 
-	QDomDocument doc( "kktemplate" );
-	QFile file( datafile );
-	if( file.open( IO_ReadOnly ) )
-	{
-		if( !doc.setContent( &file ) )
-		{
-			kdError() << i18n( "Can't analize %1" ).arg( datafile ) << endl;
-			file.close();
-			return;
-		}
-		file.close();
-	}
-	else
-	{
-		kdError() << i18n( "Can't open %1" ).arg( datafile ) << endl;
-		return;
-	}
+	QDir dir( path );
+	QStringList list = dir.entryList( QDir::Dirs|QDir::Readable, QDir::Name );
+
 	int i = 0;
-	for( QDomNode node = doc.documentElement().firstChild(); !node.isNull(); node = node.nextSibling() )
+	for( QStringList::iterator it = list.begin(); it != list.end(); ++it )
 	{
-		( new KKTCategoryItem( this, node.toElement(), path ) )->setText( 1, QString( "%1" ).arg( i++, 3 ) );
+		if( (*it)[0] != '.' )
+		{
+			KKTCategoryItem* item = new KKTCategoryItem( this, path + *it + "/" );
+			item->setText( 1, QString( "%1" ).arg( i++, QString::number( list.size() ).length() ) );
+		}
 	}
 }
